Enum term::Attr
[−]
[src]
pub enum Attr {
Bold,
Dim,
Italic(bool),
Underline(bool),
Blink,
Standout(bool),
Reverse,
Secure,
ForegroundColor(Color),
BackgroundColor(Color),
}Terminal attributes for use with term.attr().
Most attributes can only be turned on and must be turned off with term.reset(). The ones that can be turned off explicitly take a boolean value. Color is also represented as an attribute for convenience.
Variants
Bold | Bold (or possibly bright) mode | |
Dim | Dim mode, also called faint or half-bright. Often not supported | |
Italic | Italics mode. Often not supported | |
Underline | Underline mode | |
Blink | Blink mode | |
Standout | Standout mode. Often implemented as Reverse, sometimes coupled with Bold | |
Reverse | Reverse mode, inverts the foreground and background colors | |
Secure | Secure mode, also called invis mode. Hides the printed text | |
ForegroundColor | Convenience attribute to set the foreground color | |
BackgroundColor | Convenience attribute to set the background color |