Enum term::terminfo::Error
[−]
[src]
pub enum Error {
TermUnset,
MalformedTerminfo(String),
IoError(Error),
}A terminfo creation error.
Variants
TermUnset | TermUnset Indicates that the environment doesn't include enough information to find the terminfo entry. | |
MalformedTerminfo | MalformedTerminfo indicates that parsing the terminfo entry failed. | |
IoError | io::Error forwards any io::Errors encountered when finding or reading the terminfo entry. |